@@ -21,7 +21,9 @@ processQWData <- function(data,pCode=TRUE){
 
   qualifier <- ifelse((data$ResultDetectionConditionText == "Not Detected" | 
                     data$ResultDetectionConditionText == "Detected Not Quantified" |
-                    data$ResultMeasureValue < data$DetectionQuantitationLimitMeasure.MeasureValue),"<","")
+                    (!is.na(data$DetectionQuantitationLimitMeasure.MeasureValue) & 
+                       data$ResultMeasureValue < data$DetectionQuantitationLimitMeasure.MeasureValue)),
+                    "<","")
   
   correctedData<-ifelse((nchar(qualifier)==0),data$ResultMeasureValue,data$DetectionQuantitationLimitMeasure.MeasureValue)
   test <- data.frame(data$USGSPCode)
